latte_int: Count lattice points, compute volumes, and integrate over convex polytopes
=====================================================================================

Description
-----------

LattE (Lattice point Enumeration) Integrale solves the problems of
counting lattice points in and integration over convex polytopes.

License
-------

GPLv2


Upstream Contact
----------------

Matthias Köppe, UC Davis, CA, USA

https://www.math.ucdavis.edu/~latte/

https://github.com/latte-int/latte
